@@ -3,13 +3,14 @@ import types, pyarrow.parquet as pq, re
 from pathlib import Path
 from logger import logger
 
+# TODO add nested namespace support
 def load(brick,org="biobricks-ai"):
     bdir = bblib() / org / brick
     if not bdir.exists(): 
         raise Exception(f"no path '{bdir}' try `biobricks.pull({brick})`")
        
     def dirns(dir: Path):
-        filter = lambda d: d.is_dir() and d.name.endswith('.parquet')
+        filter = lambda d: d.name.endswith('.parquet')
         paths = [d for d in dir.rglob('*') if filter(d)]
         namespace = types.SimpleNamespace()
         pkey = lambda p: re.sub(r'[.-]','_',p)
